==> tkScenarist-1.0.5.tar.gz: tkScenarist-1.0.5/tkScenarist/src/application.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""
    tkScenarist - screen writing made simpler

    Copyright (c) 2014+ Raphaël Seban <motus@laposte.net>

    This program is free software: you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation, either version 3 of
    the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.

    If not, see http://www.gnu.org/licenses/
"""

import tkRAD

#~ tkRAD.i18n.switch_off()


class Application (tkRAD.RADApplication):

    APP = {
        "name": _("tkScenarist"),
        "version": _("1.0.5"),
        "description": _("Movie scriptwriting utility program."),
        "title": _("tkScenarist - screen writing made simpler"),
        "author": _("Raphaël SEBAN <motus@laposte.net>"),
        # current maintainer (may be different from author)
        "maintainer": _("Raphaël SEBAN"),
        "copyright": _("(c) 2014+ Raphaël SEBAN."),
        "license": _("Licensed under GNU General Public License v3."),
        "license_url": _("http://www.gnu.org/licenses/"),
        "pdflib": _("ReportLab®"),
        "pdflib_author": _("(c) ReportLab Europe Ltd. 2000-2012"),
    }

    DIRECTORIES = (
        "data", "etc", "html", "locale", "reportlab", "src", "tkRAD",
        "xml",
    )

    PYTHON = {
        "version": "3.3",
        "strict": False,
    }

    RC_OPTIONS = {
        "user_file": "user_options.rc",
        "user_dir": "^/etc",
        "app_file": "application.rc",
        "app_dir": "^/etc",
    }


    def _init_root_dir (self, **kw):
        pass
    # end def


    def _start_gui (self, **kw):
        self.init_root_window()
        self.init_splash_screen()
        self.show_splash_screen()
        import src.mainwindow as MW
        self.mainwindow = MW.MainWindow(**kw)
        self.mainwindow.run()
    # end def


    def hide_splash_screen (self, *args, **kw):
        try:
            self.splash.hide()
        except:
            pass
        # end try
    # end def


    def init_root_window (self, *args, **kw):
        from tkinter import Tk
        self.root = Tk()
        self.root.withdraw()
        self.root.lift()
    # end def


    def init_splash_screen (self, *args, **kw):
        from src import splash_screen as SP
        self.splash = SP.SplashScreen(
            self.root,
            app_name=self.APP["name"],
        )
    # end def


    def keep_under_splash_screen (self, window):
        try:
            window.lower(self.splash)
        except:
            pass
        # end try
    # end def


    def show_splash_screen (self, *args, **kw):
        try:
            self.splash.show()
        except:
            pass
        # end try
    # end def

# end class

==> tkScenarist-1.1.3.tar.gz: tkScenarist-1.1.3/tkScenarist/src/application.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""
    tkScenarist - screen writing made simpler

    Copyright (c) 2014+ Raphaël Seban <motus@laposte.net>

    This program is free software: you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation, either version 3 of
    the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.

    If not, see http://www.gnu.org/licenses/
"""

import tkRAD


#~ tkRAD.i18n.switch_off()


class Application (tkRAD.RADApplication):

    APP = {
        "name": _("tkScenarist"),
        "version": _("1.0.5"),
        "description": _("Movie scriptwriting utility program."),
        "title": _("tkScenarist - screen writing made simpler"),
        "author": _("Raphaël SEBAN <motus@laposte.net>"),
        # current maintainer (may be different from author)
        "maintainer": _("Raphaël SEBAN"),
        "copyright": _("(c) 2014+ Raphaël SEBAN."),
        "license": _("Licensed under GNU General Public License v3."),
        "license_url": _("http://www.gnu.org/licenses/"),
        "pdflib": _("ReportLab®"),
        "pdflib_author": _("(c) ReportLab Europe Ltd. 2000-2012"),
    }

    DIRECTORIES = (
        "data", "etc", "html", "locale", "reportlab", "src", "tkRAD",
        "xml",
    )

    PYTHON = {
        "version": "3.3",
        "strict": False,
    }

    RC_OPTIONS = {
        "user_file": "user_options.rc",
        "user_dir": "^/etc",
        "app_file": "application.rc",
        "app_dir": "^/etc",
    }


    def _init_root_dir (self, **kw):
        import os
        from tkRAD.core import path
        path.set_app_root_dir(os.getcwd())
    # end def


    def _start_gui (self, **kw):
        self.init_root_window()
        self.init_splash_screen()
        self.show_splash_screen()
        from .mainwindow import MainWindow
        self.mainwindow = MainWindow(**kw)
        self.mainwindow.run()
    # end def


    def hide_splash_screen (self, *args, **kw):
        try:
            self.splash.hide()
        except:
            pass
        # end try
    # end def


    def init_root_window (self, *args, **kw):
        from tkinter import Tk
        self.root = Tk()
        self.root.withdraw()
        self.root.lift()
    # end def


    def init_splash_screen (self, *args, **kw):
        from .splash_screen import SplashScreen
        self.splash = SplashScreen(
            self.root, app_name=self.APP["name"],
        )
    # end def


    def keep_under_splash_screen (self, window):
        try:
            window.lower(self.splash)
        except:
            pass
        # end try
    # end def


    def show_splash_screen (self, *args, **kw):
        try:
            self.splash.show()
        except:
            pass
        # end try
    # end def

# end class
